This is Tac1, my personal test project for language and technologies.

It is basically a simple note taking app, with a text user interface (TUI).
It uses simple files to store notes and it gives simple shortcuts to interact.

In the python version it uses:
- asciimatics
- simple ini files